<?php

/**  // € // to identify files as UTF8
 * Showing a page tree from a defined page onwards
 *
 * @module          page_tree
 * @author          Wolfgang Studer
 * @copyright       2016 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.01.000 | 2016-12-17
 * @lepador_link    http://www.lepton-cms.com/lepador/modules/page_tree.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3059
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


/** ------------------------------------------------------------------------------------
 * run a get_one/all query
 * @return	*		$result-
 * @param	string	$function = __FUNCTION__
 * @param	array	$query = query string
 * @param	string	$kind = 'get_one', 'get_all', 'try_catch'
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'page_tree_execute_query' ) == FALSE ):
	function page_tree_execute_query( $function = '', $query = '', $kind = 'get_one', $page_tree_vars = array() )
	{
		// define globals;
		global $database;
		global $page_tree_debug;

		// overwrite globals with passed vars
		// needed in frontend when some vars are not properly handled by global
		if (( count( $page_tree_vars ) > 0 )
		and ( array_key_exists( 'page_tree_debug', $page_tree_vars ) == TRUE )):
			$page_tree_debug = $page_tree_vars[ 'page_tree_debug' ];
		endif;
		if ( isset( $page_tree_debug ) == FALSE ):
			$page_tree_debug = FALSE;
		endif;

		// do nothing if query is empty
		if ( strlen( $query ) == 0 ):
			return TRUE;
		endif;

		// debug
		if ( $page_tree_debug == TRUE ):
			echo $function . ': ' . $query . '<br />';
		endif;

		// create result & return
		switch ( $kind ):
		case 'get_one':
			return $database->get_one( $query );
			break;

		case 'get_all':
			$handler = $database->execute_query(
					$query,
					true,
					$result
				);
			return $result;
			break;

		case 'get_all_one':
			$handler = $database->execute_query(
					$query,
					true,
					$result
				);
			if ( count( $result ) == 1 ):
				return $result[0];
			else:
				return array();
			endif;
			break;

		case 'try_catch':
			try	
			{
				$database->query( $query );
				if ( $database->is_error() == TRUE ):
					throw new Exception('Failure during query execution with error: ' . $database->get_error() );
					return FALSE;
				endif;
			}
			catch (Exception $e)
			{
				echo 'Function: ' . $function . '<br />';
				echo 'Query...: ' . $query . '<br />';
				echo '<br />';
				echo 'Caught exception: ' . $e->getMessage() . '<br />';

				return FALSE;
			}
			return TRUE;
			break;

		endswitch;
	}
endif;

?>
