<?php

/**  // € // to identify files as UTF8
 * Showing a page tree from a defined page onwards
 *
 * @module          page_tree
 * @author          Wolfgang Studer
 * @copyright       2016 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.01.000 | 2016-12-17
 * @lepador_link    http://www.lepton-cms.com/lepador/modules/page_tree.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3059
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


/** ------------------------------------------------------------------------------------
 * build page tree
 * @return	array		$tree		= result
 * @param	int			$parent		= parent id where to start
 * @param	array		$tree		= available result so far
 * @param	string		$resultType	= trail ( menutitel page1, menutitel 1 / menutitl page1.1 )
 *									  level (-- menutitelpage 1, ---- page 1.1 )
 *									  array
 * @param	string		$keyPrefix	= prefix string to be added before the tree key (= page id)
 * @param	string		$addRoot	= when set, root string is added on top
 * @param	array		$page_tree_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'page_tree_build_page_tree' ) == FALSE ):
	function page_tree_build_page_tree( $parent = 0, $tree = array(), $resultType = 'level', $keyPrefix = '', $addRoot = '', $page_tree_vars = array() )
	{
		// initialize array used inside only
		$pageTitles = array();

		// add root element
		if (( strlen( $addRoot ) > 0 ) and ( $addRoot == '1' )):
			$tree = page_tree_add_root_in_page_tree( $parent, $tree, $resultType, $keyPrefix, $addRoot, $page_tree_vars );
			$addRoot = TRUE;
		else:
			// main call for first page
			$tree = page_tree_build_page_tree_main( $parent, $tree, $pageTitles, $resultType, $keyPrefix, $addRoot, $page_tree_vars );
		endif;

		// return the tree
		return( page_tree_finalize_page_tree( $tree, $page_tree_vars ));
	}
endif;


/** ------------------------------------------------------------------------------------
 * build page tree
 * @return	array		$tree		= result
 * @param	int			$parent		= parent id where to start
 * @param	array		$tree		= available result so far
 * @param	array		$pageTitles	= available page titles so far
 * @param	string		$resultType	= trail ( menutitel page1, menutitel 1 / menutitl page1.1 )
 *									  level (-- menutitelpage 1, ---- page 1.1 )
 * @param	string		$keyPrefix	= prefix string to be added before the tree key (= page id)
 * @param	bool		$addRoot	= when TRUE, root string is added on top
 * @param	array		$page_tree_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'page_tree_build_page_tree_main' ) == FALSE ):
	function page_tree_build_page_tree_main( $parent, $tree, $pageTitles, $resultType, $keyPrefix, $addRoot, $page_tree_vars )
	{
		// define globals
		global $admin;

		// get list of page-trails, recursive
		$query = 'SELECT * '
				. ' FROM ' . TABLE_PREFIX . 'pages'
				. ' WHERE `parent` = ' . $parent
				. ' ORDER BY `position`'
				;
		$pages = page_tree_execute_query( __FUNCTION__, $query, 'get_all', $page_tree_vars );
		if ( count( $pages ) == 0 ):
			return( $tree );
		endif;

		// loop over retrieved pages
		foreach ( $pages as $idx => $page ):

			// check if page is visible
			if ( $admin->page_is_visible( $page ) === TRUE ):
				// create layout
				if ( $resultType == 'trail' ):
					$prefix = "";
					if ( $addRoot == TRUE ):
						$prefix = '../';
					endif;
					// cache page titles of all pages retrieved
					// surrounding with hash string is made to properly distinguish between 1 and 11 ...
					$pageTitles[ '#' . $page[ 'page_id' ] . '#' ] = $page[ 'menu_title' ];
					// prepare page trail
					$trail = '#' . str_replace( ',', '# / #', $page['page_trail'] ) . '#';
					// replace page id's in trail with page title
					$content = $prefix . str_replace( array_keys( $pageTitles ), $pageTitles, $trail );

				elseif ( $resultType == 'level' ):
					$prefix = "";
					if ( $addRoot == TRUE ):
						$prefix = '--';
					endif;
					if ( $page[ 'level' ] > 0 ):
						$prefix = str_repeat( '--', $page[ 'level' ] );
					endif;
					$content = $prefix . $page[ 'menu_title' ];

				elseif ( $resultType == 'array' ):
					$content = $page;

				else:
					// customer specific layout
					$content = page_tree_get_page_layout( $page, $addRoot, $page_tree_vars );
				endif;
				$tree[ $keyPrefix . $page[ 'page_id' ] ] = $content;

				// recursive call for child pages
				if ( $resultType == 'array' ):
					$childs = array();
					$tree[ $keyPrefix . $page[ 'page_id' ] ][ 'CHILDS' ] = page_tree_build_page_tree_main( $page[ 'page_id' ], $childs, $pageTitles, $resultType, $keyPrefix, $addRoot, $page_tree_vars );
				else:
					$tree = page_tree_build_page_tree_main( $page[ 'page_id' ], $tree, $pageTitles, $resultType, $keyPrefix, $addRoot, $page_tree_vars );
				endif;
			endif;
		endforeach;

		// return the tree
		return( $tree );
	}
endif;


/** ------------------------------------------------------------------------------------
 * complete pagetree
 * @return	array		$tree
 * @param	array		$tree
 * @param	array		$page_tree_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'page_tree_finalize_page_tree' ) == FALSE ):
	function page_tree_finalize_page_tree( $tree, $page_tree_vars )
	{
		// overwrite globals with passed vars
		// needed in frontend when some vars are not properly handled by global
		if (( count( $page_tree_vars ) > 0 )
		and ( array_key_exists( 'MOD_PAGE_TREE', $page_tree_vars ) == TRUE )):
			$MOD_PAGE_TREE = $page_tree_vars[ 'MOD_PAGE_TREE' ];
		endif;

		// data available
		if (( count( $tree ) > 0 )
		and ( array_key_exists( 'page', $MOD_PAGE_TREE ) == TRUE )):
			// !! Do not use array_merge as it does not preserve numeric key values
			// which might be the case if keyPrefix is '' !!!
			$tree = array( '0' => $MOD_PAGE_TREE['page'] ) + $tree;
		elseif ( array_key_exists( 'nopage', $MOD_PAGE_TREE ) == TRUE ):
			$tree[''] = $MOD_PAGE_TREE['nopage'];
		endif;

		// return the tree
		return( $tree );
	}
endif;


/** ------------------------------------------------------------------------------------
 * add root string into tree
 * @return	array		$tree		= result
 * @param	int			$parent		= parent id where to start
 * @param	array		$tree		= available result so far
 * @param	string		$resultType	= trail ( menutitel page1, menutitel 1 / menutitl page1.1 )
 *									  level (-- menutitelpage 1, ---- page 1.1 )
 * @param	string		$keyPrefix	= prefix string to be added before the tree key (= page id)
 * @param	string		$addRoot	= when set, root string is added on top
 * @param	array		$page_tree_vars
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'page_tree_add_root_in_page_tree' ) == FALSE ):
	function page_tree_add_root_in_page_tree( $parent, $tree, $resultType, $keyPrefix, $addRoot, $page_tree_vars )
	{
		// root is website
		if ( $parent == 0 ):
			if ( $resultType == 'trail' ):
				$content = LEPTON_URL;

			elseif ( $resultType == 'level' ):
				$content = LEPTON_URL;

			elseif ( $resultType == 'array' ):
				$content = array( 'link'=> '', 'menu_title'=>LEPTON_URL );

			else:
				// customer specific layout
				$content = $addRoot;
			endif;
			$key = 0;
			$tree[ $keyPrefix . $key ] = $content;

		else:
			// get page
			$query = 'SELECT * '
					. ' FROM ' . TABLE_PREFIX . 'pages'
					. ' WHERE `page_id` = ' . $parent
					. ' LIMIT 1'
					;
			$page = page_tree_execute_query( __FUNCTION__, $query, 'get_all_one', $page_tree_vars );
			if ( count( $page ) == 0 ):
				return( $tree );
			endif;

			if ( $resultType == 'trail' ):
				$content = $page[ 'menu_title' ];

			elseif ( $resultType == 'level' ):
				$content = $page[ 'menu_title' ];

			elseif ( $resultType == 'array' ):
				$content = $page;

			else:
				// customer specific layout
				$content = page_tree_get_page_layout( $page, $addRoot, $page_tree_vars );
			endif;
			$key = $page[ 'page_id' ];
			$tree[ $keyPrefix . $key ] = $content;

		endif;

		// recursive call for child pages
		if ( $resultType == 'array' ):
			$childs = array();
			$pageTitles = array();
			$tree[ $keyPrefix . $key ][ 'CHILDS' ] = page_tree_build_page_tree_main( $key, $childs, $pageTitles, $resultType, $keyPrefix, $addRoot, $page_tree_vars );
		endif;

		// return the tree
		return( $tree );
	}
endif;


/** ------------------------------------------------------------------------------------
 * set lspecific ayout for page tree line
 * @return	array		$page
 * @param	array		$page
 * @param	string/bool	$addRoot	= when set, root string is added on top
 * @param	array		$page_tree_vars
 *
 * Note: This is done in a separate function in order that just this function can be replaced if wanted
 ** ------------------------------------------------------------------------------------
 */
if ( function_exists( 'page_tree_get_page_layout' ) == FALSE ):
	function page_tree_get_page_layout( $page, $addRoot, $page_tree_vars )
	{
		return $page[ 'page_id' ];
	}
endif;

?>
