<?php

/**  // € // to identify files as UTF8
 * Showing a page tree from a defined page onwards
 *
 * @module          page_tree
 * @author          Wolfgang Studer
 * @copyright       2016 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.01.000 | 2016-12-17
 * @lepador_link    http://www.lepton-cms.com/lepador/modules/page_tree.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3059
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


// check input
	$inputs = array();
	$inputs[ 'page_id' ]		= array( 'filter' => FILTER_SANITIZE_NUMBER_INT, 'required' => 1 );
	$inputs[ 'section_id' ]		= array( 'filter' => FILTER_SANITIZE_NUMBER_INT, 'required' => 1 );
	$inputs[ 'leptoken' ]		= array( 'filter' => FILTER_SANITIZE_STRING );

// set $module as current module
	$page_tree_module = 'page_tree';

// set processing initials
	unset( $twigTemplate );
	$page_tree_component = basename( __FILE__, '.php' );
	$page_tree_modulePath = dirname( __FILE__ ) . DIRECTORY_SEPARATOR;
	$includes = array();

// include the basic files at start
	// Include admin wrapper script
	$includes[]	= array( 'LOADER'=> 'require', 'FILE' => LEPTON_PATH . '/modules/admin.php' );
	// setup module initials
	$includes[]	= array( 'LOADER'=> 'require', 'FILE' => $page_tree_modulePath . 'register_initial.php' );
	include( $page_tree_modulePath . 'load_includes.php' );

	// include language registration
	$includes[]	= $page_tree_modulePath . 'register_language.php';
	// include backend config files
	$includes[]	= $page_tree_modulePath . 'lib/lib.config.php';
	$includes[]	= $page_tree_modulePath . 'lib/lib.backend.config.php';
	$includes[]	= $page_tree_templatePath . 'lib/lib.backend.config.php';
	$includes[]	= $page_tree_modulePath . 'lib/lib.backend.config.' . $page_tree_component . '.php';
	$includes[]	= $page_tree_templatePath . 'lib/lib.backend.config.' . $page_tree_component . '.php';
	// include basic functions
	$includes[]	= $page_tree_templatePath . 'lib/lib.backend.functions.' . $page_tree_component . '.php';
	$includes[]	= $page_tree_templatePath . 'lib/lib.backend.functions.php';
	$includes[]	= $page_tree_modulePath . 'lib/lib.backend.functions.' . $page_tree_component . '.php';
	$includes[]	= $page_tree_modulePath . 'lib/lib.backend.functions.php';
	// do include
	include( $page_tree_modulePath . 'load_includes.php' );

	// initialize data variable
	$data = array();

	// do input validation
	$error = page_tree_input_filter( 'GET', $_GET, $inputs );
	$page_tree_status = '';
	if ( $error != 0 ):
		$status = FALSE;
		$page_tree_status = $MOD_PAGE_TREE['ERROR']['INPUT'] . ' [ ' . $error . ' ]' . '<br />' . $inputs[$error][ 'error' ];
		unset( $inputs );

	else:
		// save input into local vars
		$page_id		= $inputs[ 'page_id' ][ 'value' ];
		$section_id		= $inputs[ 'section_id' ][ 'value' ];
		$leptoken		= $inputs[ 'leptoken' ][ 'value' ];

		unset( $inputs );

		// initialize data variable
		$data = array();

		// prepare SQL
		$query = 'SELECT * '
					. ' FROM ' . TABLE_PREFIX . 'mod_page_tree'
					. ' WHERE `page_id`		= ' . $page_id
					. '   AND `section_id`	= ' . $section_id
					. ' LIMIT 1'
					;

	// get the data
		$data = page_tree_execute_query( __FUNCTION__, $query, 'get_all_one' );

		// data manipulation
		// include data manipulation files
		$includes[]	= $page_tree_modulePath . 'lib/lib.data.php';
		$includes[]	= $page_tree_templatePath . 'lib/lib.data.php';
		$includes[]	= $page_tree_modulePath . 'lib/lib.data.' . $page_tree_component . '.php';
		$includes[]	= $page_tree_templatePath . 'lib/lib.data.' . $page_tree_component . '.php';
		include( $page_tree_modulePath . 'load_includes.php' );

		// twig processing
		// include template engine files
		global $parser, $loader;
		$includes[]	= $page_tree_modulePath . 'lib/lib.twig.formvalues.php' ;				// initial setting of formvalues
		$includes[]	= $page_tree_modulePath . 'lib/lib.twig.php' ;						// module specific formvalues
		$includes[]	= $page_tree_templatePath . 'lib/lib.twig.php' ;						// module specific formvalues
		$includes[]	= $page_tree_modulePath . 'lib/lib.twig.' . $page_tree_component . '.php' ;		// component specific formvalues
		$includes[]	= $page_tree_templatePath . 'lib/lib.twig.' . $page_tree_component . '.php' ;	// local enhancements of formvalues
		$includes[]	= array( 'LOADER'=> 'require_once', 'FILE' => $page_tree_modulePath . 'register_parser.php' );
		include( $page_tree_modulePath . 'load_includes.php' );

		// check if twig template is defined
		if ( isset( $twigTemplate ) == FALSE ):
			// define default twig template
			$twigTemplate =  $page_tree_component . '.lte';
		endif;

		// process page
		$twig_util->resolve_path( $twigTemplate );

		// buffer output
		if ( isset( $buffer ) == TRUE ):
			// start output buffer
			ob_start();
		endif;

		echo $parser->render(
			$twig_modul_namespace . $twigTemplate,
			$form_values
		);

		$status = TRUE;
	endif;

// page footer processing
	// an failure occured
	if ( $status != TRUE ):
		$admin->print_error(
					  $page_tree_status
					, $js_back
		);
	endif;

// Print admin footer
	$admin->print_footer();

?>
