<?php

/**  // € // to identify files as UTF8
 * Showing a page tree from a defined page onwards
 *
 * @module          page_tree
 * @author          Wolfgang Studer
 * @copyright       2016 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 1.01.000 | 2016-12-17
 * @lepador_link    http://www.lepton-cms.com/lepador/modules/page_tree.php
 * @forum_link      http://forum.lepton-cms.org/viewtopic.php?f=66&t=3059
*/


// include class.secure.php to protect this file and the whole CMS!
	if ( defined('LEPTON_PATH') == TRUE ):
		include(LEPTON_PATH.'/framework/class.secure.php');
	else:
		$oneback = "../";
		$root = $oneback;
		$level = 1;
		while (( $level < 10 ) && ( file_exists( $root . '/framework/class.secure.php' ) == FALSE )):
			$root .= $oneback;
			$level += 1;
		endwhile;
	
		if ( file_exists($root.'/framework/class.secure.php') == TRUE ):
			include( $root . '/framework/class.secure.php' );
		else:
			trigger_error( sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR );
		endif;
	endif;
// end include class.secure.php


// check input
	$inputs = array();
	$inputs[ 'module' ]			= array( 'filter' => FILTER_SANITIZE_STRING, 'flags' => FILTER_FLAG_STRIP_LOW|FILTER_FLAG_STRIP_HIGH, 'required' => 1, 'allowed' => array( 'page_tree' ) );
	$inputs[ 'page_id' ]		= array( 'filter' => FILTER_SANITIZE_NUMBER_INT, 'required' => 1 );
	$inputs[ 'section_id' ]		= array( 'filter' => FILTER_SANITIZE_NUMBER_INT, 'required' => 1 );
	$inputs[ 'save_target' ]	= array( 'filter' => FILTER_SANITIZE_STRING, 'required' => 1 );
	$inputs[ 'leptoken' ]		= array( 'filter' => FILTER_SANITIZE_STRING );
	$inputs[ 'preset_path' ]	= array( 'filter' => FILTER_SANITIZE_STRING, 'required' => 1 );
	$inputs[ 'preset_name' ]	= array( 'filter' => FILTER_SANITIZE_STRING, 'required' => 1 );

	// loop over input data and add into inputs array for data validation
	foreach ( array( 'options', 'properties' ) as $kind ):
		if ( array_key_exists( $kind, $_POST ) == TRUE ):
			$inputs[ $kind ] = array( 'kind' => 'array', 'id' => FALSE );

			foreach ( $_POST[ $kind ] as $key => $value ):
				$filter = array( 'filter' => FILTER_SANITIZE_STRING );
				if (( array_key_exists( 'filter', $_POST )			== TRUE )
				and ( array_key_exists( $key, $_POST[ 'filter' ] )	== TRUE )):
					$filter = json_decode( $_POST[ 'filter' ][ $key ], TRUE );
				endif;

				$inputs[ $kind ][0][ $key ] = $filter;
			endforeach;
		endif;
	endforeach;

// Tells script to update when this page was last updated
	$update_when_modified = true;

// set $module as current module
	$page_tree_module = 'page_tree';

// set processing initials
	unset( $twigTemplate );
	$page_tree_component = basename( __FILE__, '.php' );
	$page_tree_modulePath = dirname( __FILE__ ) . DIRECTORY_SEPARATOR;
	$includes = array();

// include the basic files at start
	// Include admin wrapper script
	$includes[]	= array( 'LOADER'=> 'require', 'FILE' => LEPTON_PATH . '/modules/admin.php' );
	// setup module initials
	$includes[]	= array( 'LOADER'=> 'require', 'FILE' => $page_tree_modulePath . 'register_initial.php' );
	include( $page_tree_modulePath . 'load_includes.php' );

	// include language registration
	$includes[]	= $page_tree_modulePath . 'register_language.php';
	// include backend config files
	$includes[]	= $page_tree_modulePath . 'lib/lib.config.php';
	$includes[]	= $page_tree_modulePath . 'lib/lib.backend.config.php';
	$includes[]	= $page_tree_templatePath . 'lib/lib.backend.config.php';
	$includes[]	= $page_tree_modulePath . 'lib/lib.backend.config.' . $page_tree_component . '.php';
	$includes[]	= $page_tree_templatePath . 'lib/lib.backend.config.' . $page_tree_component . '.php';
	// include basic functions
	$includes[]	= $page_tree_templatePath . 'lib/lib.backend.functions.' . $page_tree_component . '.php';
	$includes[]	= $page_tree_templatePath . 'lib/lib.backend.functions.php';
	$includes[]	= $page_tree_modulePath . 'lib/lib.backend.functions.' . $page_tree_component . '.php';
	$includes[]	= $page_tree_modulePath . 'lib/lib.backend.functions.php';
	// do include
	include( $page_tree_modulePath . 'load_includes.php' );

	// initialize data variable
	$data = array();

	// do input validation
	$error = page_tree_input_filter( 'POST', $_POST, $inputs );
	$page_tree_status = '';
	if ( $error != 0 ):
		$status = FALSE;
		$page_tree_status = $MOD_PAGE_TREE['ERROR']['INPUT'] . ' [ ' . $error . ' ]' . '<br />' . $inputs[$error][ 'error' ];
		unset( $inputs );

	else:
		// save input into local vars
		$page_id		= $inputs[ 'page_id' ][ 'value' ];
		$section_id		= $inputs[ 'section_id' ][ 'value' ];
		$save_target	= $inputs[ 'save_target' ][ 'value' ];
		$leptoken		= $inputs[ 'leptoken' ][ 'value' ];
		$preset_path	= $inputs[ 'preset_path' ][ 'value' ];
		$preset_name	= $inputs[ 'preset_name' ][ 'value' ];

		$data = array();
		foreach ( array( 'options', 'properties' ) as $kind ):
			if (( array_key_exists( $kind, $inputs )		== TRUE )
			and ( array_key_exists( '0', $inputs[ $kind ] )	== TRUE )):
				foreach ( $inputs[ $kind ][0] as $key => $items ):
					if ( array_key_exists( 'value', $items ) == TRUE ):
						$data[ $kind ][ $key ] = $items[ 'value' ];
					endif;
				endforeach;
			endif;
		endforeach;

		unset( $inputs );

		// save data processing
		// initialize process status
		$status = TRUE;

		// include data save
		if ( $status == TRUE ):
			$includes[]	= $page_tree_modulePath . '/lib/lib.save.' . $page_tree_component . '.php';
			$includes[]	= array( 'LOADER'=> 'require', 'FILE' => $page_tree_modulePath . 'lib/lib.' . $page_tree_component . '.php' );
			include( $page_tree_modulePath . 'load_includes.php' );
		endif;

		// saved successfully
		if ( $status == TRUE ):
			if (( isset( $save_anchor )	== TRUE )
			and ( strlen( $save_anchor ) > 0    )):
				$save_target .= '#' . $save_anchor;
			endif;
			$admin->print_success(
						  $MESSAGE['PAGES']['SAVED']
						, $save_target
			);
		endif;
	endif;

// page footer processing
	// an failure occured
	if ( $status != TRUE ):
		$admin->print_error(
					  $page_tree_status
					, $js_back
		);
	endif;

// Print admin footer
	$admin->print_footer();

?>
